@@ -1736,13 +1736,12 @@ class DirectoryRCS(object):
         Зафиксировать все изменения
         :return:
         """
-        if not isEmpty(self.indexdir):
-            self.movedata(self.indexdir, self.fixeddir)
+        for dn in (self.indexdir, self.workdir):
+            if not isEmpty(dn):
+                self.movedata(dn, self.fixeddir)
 
-        if path.exists(self.indexdir):
-            removeDir(self.indexdir)
-        if not isEmpty(self.workdir):
-            self.movedata(self.workdir, self.fixeddir)
+            if path.exists(dn):
+                removeDir(dn)
 
     def indexing(self):
         """
