@@ -32,7 +32,7 @@ from .common import cmpVersion
 from .files import (getProgPath, find, process, listDirectory, readFile,
                     readLinesFile, pathJoin, makeDirectory,
                     FilesError, rsync_files, RsyncOptions,
-                    removeDir, removeFileWithEmptyDirectory)
+                    removeDir, removeFileWithEmptyDirectory, FindFileType)
 from .tools import SavableIterator, ignore
 from collections import Mapping, defaultdict
 from .common import getTupleVersion
@@ -1436,3 +1436,15 @@ def get_binary_file(pkg, pkgdir):
     :return:
     """
     return pathJoin(pkgdir, "%s.tbz2" % str(pkg))
+
+
+def clear_binhost_garbage(dn):
+    """
+    Очистить директорию binhost от временных файлов
+    :param dn:
+    :return:
+    """
+    for fn in find(dn, filetype=FindFileType.RegularFile,
+                   fullpath=True):
+        if fn.endswith(".portage.lockfile") or fn.endswith(".partial"):
+            os.unlink(fn)
