@@ -22,11 +22,13 @@ from calculate.lib.utils.dracut import Dracut
 from calculate.lib.datavars import Variable, ReadonlyVariable
 from calculate.lib.utils.files import (readFile, process, listDirectory,
                                        isMount, pathJoin, Mounts)
+from calculate.lib.utils.system import SystemType
 from calculate.lib.utils.device import getUdevDeviceInfo, loadEfiVars
 from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine, \
     CmdlineParams
 
 
+
 class VariableOsArchMachine(ReadonlyVariable):
     """
     Computer architecture (i686,x86_64)
@@ -332,3 +334,11 @@ class VariableClLivePath(Variable):
     Путь до образов из которых будет формировать live меню для grub
     """
     value = "/var/calculate/linux"
+
+class VariableOsSubsystem(Variable):
+    """
+    Получить подтип системы (lxc, uml, openvz и т.д.)
+    """
+
+    def get(self):
+        return SystemType.detect()
